@@ -7,14 +7,13 @@ module PuppetForge
     class ConnectionFailure < Faraday::Middleware
       def call(env)
         @app.call(env)
-      rescue Faraday::ConnectionFailed => e
+      rescue Faraday::ConnectionFailed, Faraday::TimeoutError => e
         baseurl = env[:url].dup
-        baseurl.path = ''
-        errmsg = "Unable to connect to #{baseurl.to_s}"
+        errmsg = "Unable to connect to %{scheme}://%{host}" % { scheme: baseurl.scheme, host: baseurl.host }
         if proxy = env[:request][:proxy]
-          errmsg << " (using proxy #{proxy.uri.to_s})"
+          errmsg << " (using proxy %{proxy})" % { proxy: proxy.uri.to_s }
         end
-        errmsg << ": #{e.message}"
+        errmsg << " (for request %{path_query}): %{message}" % { message: e.message, path_query: baseurl.request_uri }
         m = Faraday::ConnectionFailed.new(errmsg)
         m.set_backtrace(e.backtrace)
         raise m
@@ -23,4 +22,4 @@ module PuppetForge
   end
 end
 
-Faraday::Middleware.register_middleware(:connection_failure => lambda { PuppetForge::Connection::ConnectionFailure })
+Faraday::Middleware.register_middleware(:connection_failure => PuppetForge::Connection::ConnectionFailure)
