@@ -4,6 +4,7 @@ require 'puppet_forge/error'
 
 require 'puppet_forge/lazy_accessors'
 require 'puppet_forge/lazy_relations'
+require 'puppet_forge/lru_cache'
 
 module PuppetForge
   module V3
@@ -53,10 +54,24 @@ module PuppetForge
           API_VERSION
         end
 
+        # @private
+        def lru_cache
+          @lru_cache ||= PuppetForge::LruCache.new
+        end
+
+        # @private
+        def lru_cache_key(*args)
+          PuppetForge::LruCache.new_key(*args)
+        end
+
         # @private
         def request(resource, item = nil, params = {}, reset_connection = false, conn_opts = {})
+          cache_key = lru_cache_key(resource, item, params)
+          cached = lru_cache.get(cache_key)
+          return cached unless cached.nil?
+
           conn(reset_connection, conn_opts) if reset_connection
-          unless conn.url_prefix =~ /^#{PuppetForge.host}/
+          unless conn.url_prefix.to_s =~ /^#{PuppetForge.host}/
             conn.url_prefix = "#{PuppetForge.host}"
           end
 
@@ -66,7 +81,12 @@ module PuppetForge
             uri_path = "v3/#{resource}/#{item}"
           end
 
-          PuppetForge::V3::Base.conn.get uri_path, params
+          # The API expects a space separated string. This allows the user to invoke it with a more natural feeling array.
+          params['endorsements'] = params['endorsements'].join(' ') if params['endorsements'].is_a? Array
+
+          result = PuppetForge::V3::Base.conn.get uri_path, params
+          lru_cache.put(cache_key, result)
+          result
         end
 
         # @private
